@@ -27,11 +27,14 @@ class Atila (mixin.MixIn):
     def set_defulat_config (self):
         from . import version_info
 
+        self.config.MEDIA_URL = '/media/'
+        self.config.STATIC_URL = '/'
         self.config.MINIFY_HTML = False
         if version_info [:2] >= (0, 8):
             self.config.JSON_ENCODER = 'utcoffset'
         else:
             self.config.JSON_ENCODER = 'utc'
+        self.config.PRETTY_JSON = False
 
     def alias (self, *args, **karg):
         name, args = skitai.alias (*args, **karg)
