@@ -37,6 +37,12 @@ class WAS (wsgiappservice.WAS):
         return base64.encodebytes (md5 (s.encode ()).digest ()) [:-3].decode ().replace ('/', '-').replace ('+', '.')
 
     # URL builders -------------------------------------------------
+    def static (self, path):
+        return self.app.static (path)
+
+    def media (self, path):
+        return self.app.media (path)
+
     def urlfor (self, thing, *args, **karg):
         # override with resource default args
         if not isinstance (thing, str) or thing.startswith ("/") or thing.find (":") == -1:
@@ -256,7 +262,7 @@ class WAS (wsgiappservice.WAS):
 
     def API (self, *args, **karg):
         api = self.response.API (*args, **karg)
-        try: api.set_json_encoder (self.app.config.get ("JSON_ENCODER"))
+        try: api.set_json_encoder (self.app.config.get ("JSON_ENCODER"), self.app.config.get ('PRETTY_JSON', False))
         except AttributeError: pass
         return api
 
@@ -278,8 +284,10 @@ class WAS (wsgiappservice.WAS):
     def File (self, *args, **karg):
         return self.response.File (*args, **karg)
 
-    def Static (self, *args, **karg):
-        return self.response.Static (*args, **karg)
+    def Static (self, uri):
+        if not uri.startswith ('/'):
+            uri = self.static (uri)
+        return self.response.Static (uri)
 
     def ProxyPass (self, alias, path, timeout = 3):
         def respond (was, rs):
